# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class IndexSearchResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'index_search_result_type': 'str',
        'search_index_key': 'SearchIndexKey',
        'index_search_result_key': 'IndexSearchResultKey',
        'display_name': 'str',
        'short_description': 'str',
        'highlight': 'Highlight'
    }

    attribute_map = {
        'index_search_result_type': 'indexSearchResultType',
        'search_index_key': 'searchIndexKey',
        'index_search_result_key': 'indexSearchResultKey',
        'display_name': 'displayName',
        'short_description': 'shortDescription',
        'highlight': 'highlight'
    }

    def __init__(self, index_search_result_type=None, search_index_key=None, index_search_result_key=None, display_name=None, short_description=None, highlight=None):  # noqa: E501
        """IndexSearchResult - a model defined in OpenAPI"""  # noqa: E501

        self._index_search_result_type = None
        self._search_index_key = None
        self._index_search_result_key = None
        self._display_name = None
        self._short_description = None
        self._highlight = None
        self.discriminator = None

        self.index_search_result_type = index_search_result_type
        if search_index_key is not None:
            self.search_index_key = search_index_key
        self.index_search_result_key = index_search_result_key
        if display_name is not None:
            self.display_name = display_name
        if short_description is not None:
            self.short_description = short_description
        if highlight is not None:
            self.highlight = highlight

    @property
    def index_search_result_type(self):
        """Gets the index_search_result_type of this IndexSearchResult.  # noqa: E501

        The type of the index from which search results are fetched. One of the following values: BUS_OBJCT_DFNTN, TAG                  # noqa: E501

        :return: The index_search_result_type of this IndexSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._index_search_result_type

    @index_search_result_type.setter
    def index_search_result_type(self, index_search_result_type):
        """Sets the index_search_result_type of this IndexSearchResult.

        The type of the index from which search results are fetched. One of the following values: BUS_OBJCT_DFNTN, TAG                  # noqa: E501

        :param index_search_result_type: The index_search_result_type of this IndexSearchResult.  # noqa: E501
        :type: str
        """
        if index_search_result_type is None:
            raise ValueError("Invalid value for `index_search_result_type`, must not be `None`")  # noqa: E501

        self._index_search_result_type = index_search_result_type

    @property
    def search_index_key(self):
        """Gets the search_index_key of this IndexSearchResult.  # noqa: E501


        :return: The search_index_key of this IndexSearchResult.  # noqa: E501
        :rtype: SearchIndexKey
        """
        return self._search_index_key

    @search_index_key.setter
    def search_index_key(self, search_index_key):
        """Sets the search_index_key of this IndexSearchResult.


        :param search_index_key: The search_index_key of this IndexSearchResult.  # noqa: E501
        :type: SearchIndexKey
        """

        self._search_index_key = search_index_key

    @property
    def index_search_result_key(self):
        """Gets the index_search_result_key of this IndexSearchResult.  # noqa: E501


        :return: The index_search_result_key of this IndexSearchResult.  # noqa: E501
        :rtype: IndexSearchResultKey
        """
        return self._index_search_result_key

    @index_search_result_key.setter
    def index_search_result_key(self, index_search_result_key):
        """Sets the index_search_result_key of this IndexSearchResult.


        :param index_search_result_key: The index_search_result_key of this IndexSearchResult.  # noqa: E501
        :type: IndexSearchResultKey
        """
        if index_search_result_key is None:
            raise ValueError("Invalid value for `index_search_result_key`, must not be `None`")  # noqa: E501

        self._index_search_result_key = index_search_result_key

    @property
    def display_name(self):
        """Gets the display_name of this IndexSearchResult.  # noqa: E501

        The display name of the tag or business object definition  # noqa: E501

        :return: The display_name of this IndexSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this IndexSearchResult.

        The display name of the tag or business object definition  # noqa: E501

        :param display_name: The display_name of this IndexSearchResult.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def short_description(self):
        """Gets the short_description of this IndexSearchResult.  # noqa: E501

        An optional short-description. This is actually the 'description' field truncated to a configurable number of characters                  # noqa: E501

        :return: The short_description of this IndexSearchResult.  # noqa: E501
        :rtype: str
        """
        return self._short_description

    @short_description.setter
    def short_description(self, short_description):
        """Sets the short_description of this IndexSearchResult.

        An optional short-description. This is actually the 'description' field truncated to a configurable number of characters                  # noqa: E501

        :param short_description: The short_description of this IndexSearchResult.  # noqa: E501
        :type: str
        """

        self._short_description = short_description

    @property
    def highlight(self):
        """Gets the highlight of this IndexSearchResult.  # noqa: E501


        :return: The highlight of this IndexSearchResult.  # noqa: E501
        :rtype: Highlight
        """
        return self._highlight

    @highlight.setter
    def highlight(self, highlight):
        """Sets the highlight of this IndexSearchResult.


        :param highlight: The highlight of this IndexSearchResult.  # noqa: E501
        :type: Highlight
        """

        self._highlight = highlight

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IndexSearchResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class EmrClusterDefinition(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ssh_key_pair_name': 'str',
        'subnet_id': 'str',
        'log_bucket': 'str',
        'keep_alive': 'bool',
        'visible_to_all': 'bool',
        'termination_protection': 'bool',
        'encryption_enabled': 'bool',
        'account_id': 'str',
        'service_iam_role': 'str',
        'ec2_node_iam_profile_name': 'str',
        'ami_version': 'str',
        'release_label': 'str',
        'hadoop_version': 'str',
        'hive_version': 'str',
        'pig_version': 'str',
        'install_oozie': 'bool',
        'custom_bootstrap_action_master': 'list[ScriptDefinition]',
        'custom_bootstrap_action_all': 'list[ScriptDefinition]',
        'additional_info': 'str',
        'instance_definitions': 'InstanceDefinitions',
        'instance_fleet_minimum_ip_available_filter': 'int',
        'instance_fleets': 'list[EmrClusterDefinitionInstanceFleet]',
        'node_tags': 'list[NodeTag]',
        'supported_product': 'str',
        'applications': 'list[EmrClusterDefinitionApplication]',
        'configurations': 'list[EmrClusterDefinitionConfiguration]',
        'daemon_configurations': 'list[Parameter]',
        'hadoop_configurations': 'list[str]',
        'hadoop_jar_steps': 'list[HadoopJarStep]',
        'additional_master_security_groups': 'list[str]',
        'additional_slave_security_groups': 'list[str]',
        'security_configuration': 'str',
        'master_security_group': 'str',
        'slave_security_group': 'str',
        'service_access_security_group': 'str',
        'scale_down_behavior': 'str',
        'kerberos_attributes': 'EmrClusterDefinitionKerberosAttributes',
        'step_concurrency_level': 'int',
        'auto_termination_policy': 'EmrClusterDefinitionAutoTerminationPolicy'
    }

    attribute_map = {
        'ssh_key_pair_name': 'sshKeyPairName',
        'subnet_id': 'subnetId',
        'log_bucket': 'logBucket',
        'keep_alive': 'keepAlive',
        'visible_to_all': 'visibleToAll',
        'termination_protection': 'terminationProtection',
        'encryption_enabled': 'encryptionEnabled',
        'account_id': 'accountId',
        'service_iam_role': 'serviceIamRole',
        'ec2_node_iam_profile_name': 'ec2NodeIamProfileName',
        'ami_version': 'amiVersion',
        'release_label': 'releaseLabel',
        'hadoop_version': 'hadoopVersion',
        'hive_version': 'hiveVersion',
        'pig_version': 'pigVersion',
        'install_oozie': 'installOozie',
        'custom_bootstrap_action_master': 'customBootstrapActionMaster',
        'custom_bootstrap_action_all': 'customBootstrapActionAll',
        'additional_info': 'additionalInfo',
        'instance_definitions': 'instanceDefinitions',
        'instance_fleet_minimum_ip_available_filter': 'instanceFleetMinimumIpAvailableFilter',
        'instance_fleets': 'instanceFleets',
        'node_tags': 'nodeTags',
        'supported_product': 'supportedProduct',
        'applications': 'applications',
        'configurations': 'configurations',
        'daemon_configurations': 'daemonConfigurations',
        'hadoop_configurations': 'hadoopConfigurations',
        'hadoop_jar_steps': 'hadoopJarSteps',
        'additional_master_security_groups': 'additionalMasterSecurityGroups',
        'additional_slave_security_groups': 'additionalSlaveSecurityGroups',
        'security_configuration': 'securityConfiguration',
        'master_security_group': 'masterSecurityGroup',
        'slave_security_group': 'slaveSecurityGroup',
        'service_access_security_group': 'serviceAccessSecurityGroup',
        'scale_down_behavior': 'scaleDownBehavior',
        'kerberos_attributes': 'kerberosAttributes',
        'step_concurrency_level': 'stepConcurrencyLevel',
        'auto_termination_policy': 'autoTerminationPolicy'
    }

    def __init__(self, ssh_key_pair_name=None, subnet_id=None, log_bucket=None, keep_alive=None, visible_to_all=None, termination_protection=None, encryption_enabled=None, account_id=None, service_iam_role=None, ec2_node_iam_profile_name=None, ami_version=None, release_label=None, hadoop_version=None, hive_version=None, pig_version=None, install_oozie=None, custom_bootstrap_action_master=None, custom_bootstrap_action_all=None, additional_info=None, instance_definitions=None, instance_fleet_minimum_ip_available_filter=None, instance_fleets=None, node_tags=None, supported_product=None, applications=None, configurations=None, daemon_configurations=None, hadoop_configurations=None, hadoop_jar_steps=None, additional_master_security_groups=None, additional_slave_security_groups=None, security_configuration=None, master_security_group=None, slave_security_group=None, service_access_security_group=None, scale_down_behavior=None, kerberos_attributes=None, step_concurrency_level=None, auto_termination_policy=None):  # noqa: E501
        """EmrClusterDefinition - a model defined in OpenAPI"""  # noqa: E501

        self._ssh_key_pair_name = None
        self._subnet_id = None
        self._log_bucket = None
        self._keep_alive = None
        self._visible_to_all = None
        self._termination_protection = None
        self._encryption_enabled = None
        self._account_id = None
        self._service_iam_role = None
        self._ec2_node_iam_profile_name = None
        self._ami_version = None
        self._release_label = None
        self._hadoop_version = None
        self._hive_version = None
        self._pig_version = None
        self._install_oozie = None
        self._custom_bootstrap_action_master = None
        self._custom_bootstrap_action_all = None
        self._additional_info = None
        self._instance_definitions = None
        self._instance_fleet_minimum_ip_available_filter = None
        self._instance_fleets = None
        self._node_tags = None
        self._supported_product = None
        self._applications = None
        self._configurations = None
        self._daemon_configurations = None
        self._hadoop_configurations = None
        self._hadoop_jar_steps = None
        self._additional_master_security_groups = None
        self._additional_slave_security_groups = None
        self._security_configuration = None
        self._master_security_group = None
        self._slave_security_group = None
        self._service_access_security_group = None
        self._scale_down_behavior = None
        self._kerberos_attributes = None
        self._step_concurrency_level = None
        self._auto_termination_policy = None
        self.discriminator = None

        if ssh_key_pair_name is not None:
            self.ssh_key_pair_name = ssh_key_pair_name
        if subnet_id is not None:
            self.subnet_id = subnet_id
        if log_bucket is not None:
            self.log_bucket = log_bucket
        if keep_alive is not None:
            self.keep_alive = keep_alive
        if visible_to_all is not None:
            self.visible_to_all = visible_to_all
        if termination_protection is not None:
            self.termination_protection = termination_protection
        if encryption_enabled is not None:
            self.encryption_enabled = encryption_enabled
        if account_id is not None:
            self.account_id = account_id
        if service_iam_role is not None:
            self.service_iam_role = service_iam_role
        if ec2_node_iam_profile_name is not None:
            self.ec2_node_iam_profile_name = ec2_node_iam_profile_name
        if ami_version is not None:
            self.ami_version = ami_version
        if release_label is not None:
            self.release_label = release_label
        if hadoop_version is not None:
            self.hadoop_version = hadoop_version
        if hive_version is not None:
            self.hive_version = hive_version
        if pig_version is not None:
            self.pig_version = pig_version
        if install_oozie is not None:
            self.install_oozie = install_oozie
        if custom_bootstrap_action_master is not None:
            self.custom_bootstrap_action_master = custom_bootstrap_action_master
        if custom_bootstrap_action_all is not None:
            self.custom_bootstrap_action_all = custom_bootstrap_action_all
        if additional_info is not None:
            self.additional_info = additional_info
        if instance_definitions is not None:
            self.instance_definitions = instance_definitions
        if instance_fleet_minimum_ip_available_filter is not None:
            self.instance_fleet_minimum_ip_available_filter = instance_fleet_minimum_ip_available_filter
        if instance_fleets is not None:
            self.instance_fleets = instance_fleets
        if node_tags is not None:
            self.node_tags = node_tags
        if supported_product is not None:
            self.supported_product = supported_product
        if applications is not None:
            self.applications = applications
        if configurations is not None:
            self.configurations = configurations
        if daemon_configurations is not None:
            self.daemon_configurations = daemon_configurations
        if hadoop_configurations is not None:
            self.hadoop_configurations = hadoop_configurations
        if hadoop_jar_steps is not None:
            self.hadoop_jar_steps = hadoop_jar_steps
        if additional_master_security_groups is not None:
            self.additional_master_security_groups = additional_master_security_groups
        if additional_slave_security_groups is not None:
            self.additional_slave_security_groups = additional_slave_security_groups
        if security_configuration is not None:
            self.security_configuration = security_configuration
        if master_security_group is not None:
            self.master_security_group = master_security_group
        if slave_security_group is not None:
            self.slave_security_group = slave_security_group
        if service_access_security_group is not None:
            self.service_access_security_group = service_access_security_group
        if scale_down_behavior is not None:
            self.scale_down_behavior = scale_down_behavior
        if kerberos_attributes is not None:
            self.kerberos_attributes = kerberos_attributes
        if step_concurrency_level is not None:
            self.step_concurrency_level = step_concurrency_level
        if auto_termination_policy is not None:
            self.auto_termination_policy = auto_termination_policy

    @property
    def ssh_key_pair_name(self):
        """Gets the ssh_key_pair_name of this EmrClusterDefinition.  # noqa: E501

        The name of the Amazon EC2 key pair to set as the connection credential  # noqa: E501

        :return: The ssh_key_pair_name of this EmrClusterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._ssh_key_pair_name

    @ssh_key_pair_name.setter
    def ssh_key_pair_name(self, ssh_key_pair_name):
        """Sets the ssh_key_pair_name of this EmrClusterDefinition.

        The name of the Amazon EC2 key pair to set as the connection credential  # noqa: E501

        :param ssh_key_pair_name: The ssh_key_pair_name of this EmrClusterDefinition.  # noqa: E501
        :type: str
        """

        self._ssh_key_pair_name = ssh_key_pair_name

    @property
    def subnet_id(self):
        """Gets the subnet_id of this EmrClusterDefinition.  # noqa: E501

        <p>A comma separated list of Amazon VPC subnets.</p>                   <ul>                   <li>When multiple subnets are specified, the subnet in the AZ with the best price will be used.</li>                   <li>When multiple subnets belong to the same AZ, the subnet with the largest amount of available IP's will be used.</li>                   </ul>                   <p>Cross-VPC access in PROD will only accept internal/emr subnets at this time.</p>                  # noqa: E501

        :return: The subnet_id of this EmrClusterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """Sets the subnet_id of this EmrClusterDefinition.

        <p>A comma separated list of Amazon VPC subnets.</p>                   <ul>                   <li>When multiple subnets are specified, the subnet in the AZ with the best price will be used.</li>                   <li>When multiple subnets belong to the same AZ, the subnet with the largest amount of available IP's will be used.</li>                   </ul>                   <p>Cross-VPC access in PROD will only accept internal/emr subnets at this time.</p>                  # noqa: E501

        :param subnet_id: The subnet_id of this EmrClusterDefinition.  # noqa: E501
        :type: str
        """

        self._subnet_id = subnet_id

    @property
    def log_bucket(self):
        """Gets the log_bucket of this EmrClusterDefinition.  # noqa: E501

        Amazon S3 bucket to receive log files  # noqa: E501

        :return: The log_bucket of this EmrClusterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._log_bucket

    @log_bucket.setter
    def log_bucket(self, log_bucket):
        """Sets the log_bucket of this EmrClusterDefinition.

        Amazon S3 bucket to receive log files  # noqa: E501

        :param log_bucket: The log_bucket of this EmrClusterDefinition.  # noqa: E501
        :type: str
        """

        self._log_bucket = log_bucket

    @property
    def keep_alive(self):
        """Gets the keep_alive of this EmrClusterDefinition.  # noqa: E501

        Launch a cluster that continues running even after completing all its steps  # noqa: E501

        :return: The keep_alive of this EmrClusterDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._keep_alive

    @keep_alive.setter
    def keep_alive(self, keep_alive):
        """Sets the keep_alive of this EmrClusterDefinition.

        Launch a cluster that continues running even after completing all its steps  # noqa: E501

        :param keep_alive: The keep_alive of this EmrClusterDefinition.  # noqa: E501
        :type: bool
        """

        self._keep_alive = keep_alive

    @property
    def visible_to_all(self):
        """Gets the visible_to_all of this EmrClusterDefinition.  # noqa: E501

        Makes the instances in an existing cluster visible to all IAM users  # noqa: E501

        :return: The visible_to_all of this EmrClusterDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._visible_to_all

    @visible_to_all.setter
    def visible_to_all(self, visible_to_all):
        """Sets the visible_to_all of this EmrClusterDefinition.

        Makes the instances in an existing cluster visible to all IAM users  # noqa: E501

        :param visible_to_all: The visible_to_all of this EmrClusterDefinition.  # noqa: E501
        :type: bool
        """

        self._visible_to_all = visible_to_all

    @property
    def termination_protection(self):
        """Gets the termination_protection of this EmrClusterDefinition.  # noqa: E501

        Launch the cluster with termination protection enabled  # noqa: E501

        :return: The termination_protection of this EmrClusterDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._termination_protection

    @termination_protection.setter
    def termination_protection(self, termination_protection):
        """Sets the termination_protection of this EmrClusterDefinition.

        Launch the cluster with termination protection enabled  # noqa: E501

        :param termination_protection: The termination_protection of this EmrClusterDefinition.  # noqa: E501
        :type: bool
        """

        self._termination_protection = termination_protection

    @property
    def encryption_enabled(self):
        """Gets the encryption_enabled of this EmrClusterDefinition.  # noqa: E501

        Volume level encryption for the disks (using custom scripts). Encryption is not supported for AMI versions lower than                   3.1.0                  # noqa: E501

        :return: The encryption_enabled of this EmrClusterDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._encryption_enabled

    @encryption_enabled.setter
    def encryption_enabled(self, encryption_enabled):
        """Sets the encryption_enabled of this EmrClusterDefinition.

        Volume level encryption for the disks (using custom scripts). Encryption is not supported for AMI versions lower than                   3.1.0                  # noqa: E501

        :param encryption_enabled: The encryption_enabled of this EmrClusterDefinition.  # noqa: E501
        :type: bool
        """

        self._encryption_enabled = encryption_enabled

    @property
    def account_id(self):
        """Gets the account_id of this EmrClusterDefinition.  # noqa: E501

        The AWS account number, without dashes, to launch the Amazon EMR service in  # noqa: E501

        :return: The account_id of this EmrClusterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this EmrClusterDefinition.

        The AWS account number, without dashes, to launch the Amazon EMR service in  # noqa: E501

        :param account_id: The account_id of this EmrClusterDefinition.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def service_iam_role(self):
        """Gets the service_iam_role of this EmrClusterDefinition.  # noqa: E501

        Launches the Amazon EMR service with the specified IAM role  # noqa: E501

        :return: The service_iam_role of this EmrClusterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._service_iam_role

    @service_iam_role.setter
    def service_iam_role(self, service_iam_role):
        """Sets the service_iam_role of this EmrClusterDefinition.

        Launches the Amazon EMR service with the specified IAM role  # noqa: E501

        :param service_iam_role: The service_iam_role of this EmrClusterDefinition.  # noqa: E501
        :type: str
        """

        self._service_iam_role = service_iam_role

    @property
    def ec2_node_iam_profile_name(self):
        """Gets the ec2_node_iam_profile_name of this EmrClusterDefinition.  # noqa: E501

        Launches the EC2 instances of a cluster with the specified IAM role  # noqa: E501

        :return: The ec2_node_iam_profile_name of this EmrClusterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._ec2_node_iam_profile_name

    @ec2_node_iam_profile_name.setter
    def ec2_node_iam_profile_name(self, ec2_node_iam_profile_name):
        """Sets the ec2_node_iam_profile_name of this EmrClusterDefinition.

        Launches the EC2 instances of a cluster with the specified IAM role  # noqa: E501

        :param ec2_node_iam_profile_name: The ec2_node_iam_profile_name of this EmrClusterDefinition.  # noqa: E501
        :type: str
        """

        self._ec2_node_iam_profile_name = ec2_node_iam_profile_name

    @property
    def ami_version(self):
        """Gets the ami_version of this EmrClusterDefinition.  # noqa: E501

        Specify the version of the AMI to use  # noqa: E501

        :return: The ami_version of this EmrClusterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._ami_version

    @ami_version.setter
    def ami_version(self, ami_version):
        """Sets the ami_version of this EmrClusterDefinition.

        Specify the version of the AMI to use  # noqa: E501

        :param ami_version: The ami_version of this EmrClusterDefinition.  # noqa: E501
        :type: str
        """

        self._ami_version = ami_version

    @property
    def release_label(self):
        """Gets the release_label of this EmrClusterDefinition.  # noqa: E501

        The release label. Available from 4.x  # noqa: E501

        :return: The release_label of this EmrClusterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._release_label

    @release_label.setter
    def release_label(self, release_label):
        """Sets the release_label of this EmrClusterDefinition.

        The release label. Available from 4.x  # noqa: E501

        :param release_label: The release_label of this EmrClusterDefinition.  # noqa: E501
        :type: str
        """

        self._release_label = release_label

    @property
    def hadoop_version(self):
        """Gets the hadoop_version of this EmrClusterDefinition.  # noqa: E501

        Specify the version of Hadoop to install  # noqa: E501

        :return: The hadoop_version of this EmrClusterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._hadoop_version

    @hadoop_version.setter
    def hadoop_version(self, hadoop_version):
        """Sets the hadoop_version of this EmrClusterDefinition.

        Specify the version of Hadoop to install  # noqa: E501

        :param hadoop_version: The hadoop_version of this EmrClusterDefinition.  # noqa: E501
        :type: str
        """

        self._hadoop_version = hadoop_version

    @property
    def hive_version(self):
        """Gets the hive_version of this EmrClusterDefinition.  # noqa: E501

        The Hive version to load  # noqa: E501

        :return: The hive_version of this EmrClusterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._hive_version

    @hive_version.setter
    def hive_version(self, hive_version):
        """Sets the hive_version of this EmrClusterDefinition.

        The Hive version to load  # noqa: E501

        :param hive_version: The hive_version of this EmrClusterDefinition.  # noqa: E501
        :type: str
        """

        self._hive_version = hive_version

    @property
    def pig_version(self):
        """Gets the pig_version of this EmrClusterDefinition.  # noqa: E501

        The Pig version to load  # noqa: E501

        :return: The pig_version of this EmrClusterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._pig_version

    @pig_version.setter
    def pig_version(self, pig_version):
        """Sets the pig_version of this EmrClusterDefinition.

        The Pig version to load  # noqa: E501

        :param pig_version: The pig_version of this EmrClusterDefinition.  # noqa: E501
        :type: str
        """

        self._pig_version = pig_version

    @property
    def install_oozie(self):
        """Gets the install_oozie of this EmrClusterDefinition.  # noqa: E501


        :return: The install_oozie of this EmrClusterDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._install_oozie

    @install_oozie.setter
    def install_oozie(self, install_oozie):
        """Sets the install_oozie of this EmrClusterDefinition.


        :param install_oozie: The install_oozie of this EmrClusterDefinition.  # noqa: E501
        :type: bool
        """

        self._install_oozie = install_oozie

    @property
    def custom_bootstrap_action_master(self):
        """Gets the custom_bootstrap_action_master of this EmrClusterDefinition.  # noqa: E501

        Bootstrapping scripts that are executed only on the Master node  # noqa: E501

        :return: The custom_bootstrap_action_master of this EmrClusterDefinition.  # noqa: E501
        :rtype: list[ScriptDefinition]
        """
        return self._custom_bootstrap_action_master

    @custom_bootstrap_action_master.setter
    def custom_bootstrap_action_master(self, custom_bootstrap_action_master):
        """Sets the custom_bootstrap_action_master of this EmrClusterDefinition.

        Bootstrapping scripts that are executed only on the Master node  # noqa: E501

        :param custom_bootstrap_action_master: The custom_bootstrap_action_master of this EmrClusterDefinition.  # noqa: E501
        :type: list[ScriptDefinition]
        """

        self._custom_bootstrap_action_master = custom_bootstrap_action_master

    @property
    def custom_bootstrap_action_all(self):
        """Gets the custom_bootstrap_action_all of this EmrClusterDefinition.  # noqa: E501

        Bootstrapping scripts that are executed on all the nodes  # noqa: E501

        :return: The custom_bootstrap_action_all of this EmrClusterDefinition.  # noqa: E501
        :rtype: list[ScriptDefinition]
        """
        return self._custom_bootstrap_action_all

    @custom_bootstrap_action_all.setter
    def custom_bootstrap_action_all(self, custom_bootstrap_action_all):
        """Sets the custom_bootstrap_action_all of this EmrClusterDefinition.

        Bootstrapping scripts that are executed on all the nodes  # noqa: E501

        :param custom_bootstrap_action_all: The custom_bootstrap_action_all of this EmrClusterDefinition.  # noqa: E501
        :type: list[ScriptDefinition]
        """

        self._custom_bootstrap_action_all = custom_bootstrap_action_all

    @property
    def additional_info(self):
        """Gets the additional_info of this EmrClusterDefinition.  # noqa: E501

        Specifies additional information during cluster creation  # noqa: E501

        :return: The additional_info of this EmrClusterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._additional_info

    @additional_info.setter
    def additional_info(self, additional_info):
        """Sets the additional_info of this EmrClusterDefinition.

        Specifies additional information during cluster creation  # noqa: E501

        :param additional_info: The additional_info of this EmrClusterDefinition.  # noqa: E501
        :type: str
        """

        self._additional_info = additional_info

    @property
    def instance_definitions(self):
        """Gets the instance_definitions of this EmrClusterDefinition.  # noqa: E501


        :return: The instance_definitions of this EmrClusterDefinition.  # noqa: E501
        :rtype: InstanceDefinitions
        """
        return self._instance_definitions

    @instance_definitions.setter
    def instance_definitions(self, instance_definitions):
        """Sets the instance_definitions of this EmrClusterDefinition.


        :param instance_definitions: The instance_definitions of this EmrClusterDefinition.  # noqa: E501
        :type: InstanceDefinitions
        """

        self._instance_definitions = instance_definitions

    @property
    def instance_fleet_minimum_ip_available_filter(self):
        """Gets the instance_fleet_minimum_ip_available_filter of this EmrClusterDefinition.  # noqa: E501

        Specifies minimum number of available IPs required for the instance fleet  # noqa: E501

        :return: The instance_fleet_minimum_ip_available_filter of this EmrClusterDefinition.  # noqa: E501
        :rtype: int
        """
        return self._instance_fleet_minimum_ip_available_filter

    @instance_fleet_minimum_ip_available_filter.setter
    def instance_fleet_minimum_ip_available_filter(self, instance_fleet_minimum_ip_available_filter):
        """Sets the instance_fleet_minimum_ip_available_filter of this EmrClusterDefinition.

        Specifies minimum number of available IPs required for the instance fleet  # noqa: E501

        :param instance_fleet_minimum_ip_available_filter: The instance_fleet_minimum_ip_available_filter of this EmrClusterDefinition.  # noqa: E501
        :type: int
        """

        self._instance_fleet_minimum_ip_available_filter = instance_fleet_minimum_ip_available_filter

    @property
    def instance_fleets(self):
        """Gets the instance_fleets of this EmrClusterDefinition.  # noqa: E501

        Describes the EC2 instances and instance configurations for clusters that use the instance fleet configuration. The instance                   fleet configuration is available only in Amazon EMR versions 4.8.0 and later, excluding 5.0.x versions                  # noqa: E501

        :return: The instance_fleets of this EmrClusterDefinition.  # noqa: E501
        :rtype: list[EmrClusterDefinitionInstanceFleet]
        """
        return self._instance_fleets

    @instance_fleets.setter
    def instance_fleets(self, instance_fleets):
        """Sets the instance_fleets of this EmrClusterDefinition.

        Describes the EC2 instances and instance configurations for clusters that use the instance fleet configuration. The instance                   fleet configuration is available only in Amazon EMR versions 4.8.0 and later, excluding 5.0.x versions                  # noqa: E501

        :param instance_fleets: The instance_fleets of this EmrClusterDefinition.  # noqa: E501
        :type: list[EmrClusterDefinitionInstanceFleet]
        """

        self._instance_fleets = instance_fleets

    @property
    def node_tags(self):
        """Gets the node_tags of this EmrClusterDefinition.  # noqa: E501

        Custom tags to be applied on the EC2 nodes  # noqa: E501

        :return: The node_tags of this EmrClusterDefinition.  # noqa: E501
        :rtype: list[NodeTag]
        """
        return self._node_tags

    @node_tags.setter
    def node_tags(self, node_tags):
        """Sets the node_tags of this EmrClusterDefinition.

        Custom tags to be applied on the EC2 nodes  # noqa: E501

        :param node_tags: The node_tags of this EmrClusterDefinition.  # noqa: E501
        :type: list[NodeTag]
        """

        self._node_tags = node_tags

    @property
    def supported_product(self):
        """Gets the supported_product of this EmrClusterDefinition.  # noqa: E501

        Installs third-party software on an Amazon EMR cluster  # noqa: E501

        :return: The supported_product of this EmrClusterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._supported_product

    @supported_product.setter
    def supported_product(self, supported_product):
        """Sets the supported_product of this EmrClusterDefinition.

        Installs third-party software on an Amazon EMR cluster  # noqa: E501

        :param supported_product: The supported_product of this EmrClusterDefinition.  # noqa: E501
        :type: str
        """

        self._supported_product = supported_product

    @property
    def applications(self):
        """Gets the applications of this EmrClusterDefinition.  # noqa: E501

        List of applications  # noqa: E501

        :return: The applications of this EmrClusterDefinition.  # noqa: E501
        :rtype: list[EmrClusterDefinitionApplication]
        """
        return self._applications

    @applications.setter
    def applications(self, applications):
        """Sets the applications of this EmrClusterDefinition.

        List of applications  # noqa: E501

        :param applications: The applications of this EmrClusterDefinition.  # noqa: E501
        :type: list[EmrClusterDefinitionApplication]
        """

        self._applications = applications

    @property
    def configurations(self):
        """Gets the configurations of this EmrClusterDefinition.  # noqa: E501

        List of configurations  # noqa: E501

        :return: The configurations of this EmrClusterDefinition.  # noqa: E501
        :rtype: list[EmrClusterDefinitionConfiguration]
        """
        return self._configurations

    @configurations.setter
    def configurations(self, configurations):
        """Sets the configurations of this EmrClusterDefinition.

        List of configurations  # noqa: E501

        :param configurations: The configurations of this EmrClusterDefinition.  # noqa: E501
        :type: list[EmrClusterDefinitionConfiguration]
        """

        self._configurations = configurations

    @property
    def daemon_configurations(self):
        """Gets the daemon_configurations of this EmrClusterDefinition.  # noqa: E501

        Predefined bootstrap action to configure hadoop daemons  # noqa: E501

        :return: The daemon_configurations of this EmrClusterDefinition.  # noqa: E501
        :rtype: list[Parameter]
        """
        return self._daemon_configurations

    @daemon_configurations.setter
    def daemon_configurations(self, daemon_configurations):
        """Sets the daemon_configurations of this EmrClusterDefinition.

        Predefined bootstrap action to configure hadoop daemons  # noqa: E501

        :param daemon_configurations: The daemon_configurations of this EmrClusterDefinition.  # noqa: E501
        :type: list[Parameter]
        """

        self._daemon_configurations = daemon_configurations

    @property
    def hadoop_configurations(self):
        """Gets the hadoop_configurations of this EmrClusterDefinition.  # noqa: E501

        Predefined bootstrap action to specify hadoop configurations  # noqa: E501

        :return: The hadoop_configurations of this EmrClusterDefinition.  # noqa: E501
        :rtype: list[str]
        """
        return self._hadoop_configurations

    @hadoop_configurations.setter
    def hadoop_configurations(self, hadoop_configurations):
        """Sets the hadoop_configurations of this EmrClusterDefinition.

        Predefined bootstrap action to specify hadoop configurations  # noqa: E501

        :param hadoop_configurations: The hadoop_configurations of this EmrClusterDefinition.  # noqa: E501
        :type: list[str]
        """

        self._hadoop_configurations = hadoop_configurations

    @property
    def hadoop_jar_steps(self):
        """Gets the hadoop_jar_steps of this EmrClusterDefinition.  # noqa: E501

        Hadoop jar steps that are added, to be executed once the cluster is started  # noqa: E501

        :return: The hadoop_jar_steps of this EmrClusterDefinition.  # noqa: E501
        :rtype: list[HadoopJarStep]
        """
        return self._hadoop_jar_steps

    @hadoop_jar_steps.setter
    def hadoop_jar_steps(self, hadoop_jar_steps):
        """Sets the hadoop_jar_steps of this EmrClusterDefinition.

        Hadoop jar steps that are added, to be executed once the cluster is started  # noqa: E501

        :param hadoop_jar_steps: The hadoop_jar_steps of this EmrClusterDefinition.  # noqa: E501
        :type: list[HadoopJarStep]
        """

        self._hadoop_jar_steps = hadoop_jar_steps

    @property
    def additional_master_security_groups(self):
        """Gets the additional_master_security_groups of this EmrClusterDefinition.  # noqa: E501

        List of additional master node security groups. The security group defined by the configuration value                   emr.herd.support.security.group will automatically be added whether this list is specified or not                  # noqa: E501

        :return: The additional_master_security_groups of this EmrClusterDefinition.  # noqa: E501
        :rtype: list[str]
        """
        return self._additional_master_security_groups

    @additional_master_security_groups.setter
    def additional_master_security_groups(self, additional_master_security_groups):
        """Sets the additional_master_security_groups of this EmrClusterDefinition.

        List of additional master node security groups. The security group defined by the configuration value                   emr.herd.support.security.group will automatically be added whether this list is specified or not                  # noqa: E501

        :param additional_master_security_groups: The additional_master_security_groups of this EmrClusterDefinition.  # noqa: E501
        :type: list[str]
        """

        self._additional_master_security_groups = additional_master_security_groups

    @property
    def additional_slave_security_groups(self):
        """Gets the additional_slave_security_groups of this EmrClusterDefinition.  # noqa: E501

        List of additional slave node security groups  # noqa: E501

        :return: The additional_slave_security_groups of this EmrClusterDefinition.  # noqa: E501
        :rtype: list[str]
        """
        return self._additional_slave_security_groups

    @additional_slave_security_groups.setter
    def additional_slave_security_groups(self, additional_slave_security_groups):
        """Sets the additional_slave_security_groups of this EmrClusterDefinition.

        List of additional slave node security groups  # noqa: E501

        :param additional_slave_security_groups: The additional_slave_security_groups of this EmrClusterDefinition.  # noqa: E501
        :type: list[str]
        """

        self._additional_slave_security_groups = additional_slave_security_groups

    @property
    def security_configuration(self):
        """Gets the security_configuration of this EmrClusterDefinition.  # noqa: E501

        The name of a security configuration to apply to the cluster  # noqa: E501

        :return: The security_configuration of this EmrClusterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._security_configuration

    @security_configuration.setter
    def security_configuration(self, security_configuration):
        """Sets the security_configuration of this EmrClusterDefinition.

        The name of a security configuration to apply to the cluster  # noqa: E501

        :param security_configuration: The security_configuration of this EmrClusterDefinition.  # noqa: E501
        :type: str
        """

        self._security_configuration = security_configuration

    @property
    def master_security_group(self):
        """Gets the master_security_group of this EmrClusterDefinition.  # noqa: E501

        The master security group to use instead of the account default value  # noqa: E501

        :return: The master_security_group of this EmrClusterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._master_security_group

    @master_security_group.setter
    def master_security_group(self, master_security_group):
        """Sets the master_security_group of this EmrClusterDefinition.

        The master security group to use instead of the account default value  # noqa: E501

        :param master_security_group: The master_security_group of this EmrClusterDefinition.  # noqa: E501
        :type: str
        """

        self._master_security_group = master_security_group

    @property
    def slave_security_group(self):
        """Gets the slave_security_group of this EmrClusterDefinition.  # noqa: E501

        The slave security group to use instead of the account default value  # noqa: E501

        :return: The slave_security_group of this EmrClusterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._slave_security_group

    @slave_security_group.setter
    def slave_security_group(self, slave_security_group):
        """Sets the slave_security_group of this EmrClusterDefinition.

        The slave security group to use instead of the account default value  # noqa: E501

        :param slave_security_group: The slave_security_group of this EmrClusterDefinition.  # noqa: E501
        :type: str
        """

        self._slave_security_group = slave_security_group

    @property
    def service_access_security_group(self):
        """Gets the service_access_security_group of this EmrClusterDefinition.  # noqa: E501

        The service access security group to use  # noqa: E501

        :return: The service_access_security_group of this EmrClusterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._service_access_security_group

    @service_access_security_group.setter
    def service_access_security_group(self, service_access_security_group):
        """Sets the service_access_security_group of this EmrClusterDefinition.

        The service access security group to use  # noqa: E501

        :param service_access_security_group: The service_access_security_group of this EmrClusterDefinition.  # noqa: E501
        :type: str
        """

        self._service_access_security_group = service_access_security_group

    @property
    def scale_down_behavior(self):
        """Gets the scale_down_behavior of this EmrClusterDefinition.  # noqa: E501

        Specifies the way that individual Amazon EC2 instances terminate when an automatic scale-in activity occurs or an instance                   group is resized. One of the following values: TERMINATE_AT_INSTANCE_HOUR or TERMINATE_AT_TASK_COMPLETION                  # noqa: E501

        :return: The scale_down_behavior of this EmrClusterDefinition.  # noqa: E501
        :rtype: str
        """
        return self._scale_down_behavior

    @scale_down_behavior.setter
    def scale_down_behavior(self, scale_down_behavior):
        """Sets the scale_down_behavior of this EmrClusterDefinition.

        Specifies the way that individual Amazon EC2 instances terminate when an automatic scale-in activity occurs or an instance                   group is resized. One of the following values: TERMINATE_AT_INSTANCE_HOUR or TERMINATE_AT_TASK_COMPLETION                  # noqa: E501

        :param scale_down_behavior: The scale_down_behavior of this EmrClusterDefinition.  # noqa: E501
        :type: str
        """

        self._scale_down_behavior = scale_down_behavior

    @property
    def kerberos_attributes(self):
        """Gets the kerberos_attributes of this EmrClusterDefinition.  # noqa: E501


        :return: The kerberos_attributes of this EmrClusterDefinition.  # noqa: E501
        :rtype: EmrClusterDefinitionKerberosAttributes
        """
        return self._kerberos_attributes

    @kerberos_attributes.setter
    def kerberos_attributes(self, kerberos_attributes):
        """Sets the kerberos_attributes of this EmrClusterDefinition.


        :param kerberos_attributes: The kerberos_attributes of this EmrClusterDefinition.  # noqa: E501
        :type: EmrClusterDefinitionKerberosAttributes
        """

        self._kerberos_attributes = kerberos_attributes

    @property
    def step_concurrency_level(self):
        """Gets the step_concurrency_level of this EmrClusterDefinition.  # noqa: E501

        The step concurrency level of the cluster. Default is 1 which is non-concurrent. The maximum value is 256  # noqa: E501

        :return: The step_concurrency_level of this EmrClusterDefinition.  # noqa: E501
        :rtype: int
        """
        return self._step_concurrency_level

    @step_concurrency_level.setter
    def step_concurrency_level(self, step_concurrency_level):
        """Sets the step_concurrency_level of this EmrClusterDefinition.

        The step concurrency level of the cluster. Default is 1 which is non-concurrent. The maximum value is 256  # noqa: E501

        :param step_concurrency_level: The step_concurrency_level of this EmrClusterDefinition.  # noqa: E501
        :type: int
        """

        self._step_concurrency_level = step_concurrency_level

    @property
    def auto_termination_policy(self):
        """Gets the auto_termination_policy of this EmrClusterDefinition.  # noqa: E501


        :return: The auto_termination_policy of this EmrClusterDefinition.  # noqa: E501
        :rtype: EmrClusterDefinitionAutoTerminationPolicy
        """
        return self._auto_termination_policy

    @auto_termination_policy.setter
    def auto_termination_policy(self, auto_termination_policy):
        """Sets the auto_termination_policy of this EmrClusterDefinition.


        :param auto_termination_policy: The auto_termination_policy of this EmrClusterDefinition.  # noqa: E501
        :type: EmrClusterDefinitionAutoTerminationPolicy
        """

        self._auto_termination_policy = auto_termination_policy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmrClusterDefinition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from herdsdk.api.allowed_attribute_value_api import AllowedAttributeValueApi
from herdsdk.api.application_api import ApplicationApi
from herdsdk.api.attribute_value_list_api import AttributeValueListApi
from herdsdk.api.business_object_data_api import BusinessObjectDataApi
from herdsdk.api.business_object_data_attribute_api import BusinessObjectDataAttributeApi
from herdsdk.api.business_object_data_notification_registration_api import BusinessObjectDataNotificationRegistrationApi
from herdsdk.api.business_object_data_status_api import BusinessObjectDataStatusApi
from herdsdk.api.business_object_data_storage_file_api import BusinessObjectDataStorageFileApi
from herdsdk.api.business_object_data_storage_unit_api import BusinessObjectDataStorageUnitApi
from herdsdk.api.business_object_data_storage_unit_status_api import BusinessObjectDataStorageUnitStatusApi
from herdsdk.api.business_object_definition_api import BusinessObjectDefinitionApi
from herdsdk.api.business_object_definition_column_api import BusinessObjectDefinitionColumnApi
from herdsdk.api.business_object_definition_description_suggestion_api import BusinessObjectDefinitionDescriptionSuggestionApi
from herdsdk.api.business_object_definition_subject_matter_expert_api import BusinessObjectDefinitionSubjectMatterExpertApi
from herdsdk.api.business_object_definition_tag_api import BusinessObjectDefinitionTagApi
from herdsdk.api.business_object_format_api import BusinessObjectFormatApi
from herdsdk.api.business_object_format_external_interface_descriptive_information_api import BusinessObjectFormatExternalInterfaceDescriptiveInformationApi
from herdsdk.api.business_object_format_to_external_interface_mapping_api import BusinessObjectFormatToExternalInterfaceMappingApi
from herdsdk.api.configuration_entry_api import ConfigurationEntryApi
from herdsdk.api.current_user_api import CurrentUserApi
from herdsdk.api.custom_ddl_api import CustomDDLApi
from herdsdk.api.data_provider_api import DataProviderApi
from herdsdk.api.emr_api import EMRApi
from herdsdk.api.emr_cluster_definition_api import EMRClusterDefinitionApi
from herdsdk.api.expected_partition_value_api import ExpectedPartitionValueApi
from herdsdk.api.external_interface_api import ExternalInterfaceApi
from herdsdk.api.file_type_api import FileTypeApi
from herdsdk.api.global_attribute_definition_api import GlobalAttributeDefinitionApi
from herdsdk.api.index_search_api import IndexSearchApi
from herdsdk.api.job_api import JobApi
from herdsdk.api.job_definition_api import JobDefinitionApi
from herdsdk.api.namespace_api import NamespaceApi
from herdsdk.api.namespace_iam_role_authorization_api import NamespaceIAMRoleAuthorizationApi
from herdsdk.api.notification_registration_status_api import NotificationRegistrationStatusApi
from herdsdk.api.partition_key_group_api import PartitionKeyGroupApi
from herdsdk.api.relational_table_registration_api import RelationalTableRegistrationApi
from herdsdk.api.search_index_api import SearchIndexApi
from herdsdk.api.search_index_activation_api import SearchIndexActivationApi
from herdsdk.api.security_function_api import SecurityFunctionApi
from herdsdk.api.security_role_api import SecurityRoleApi
from herdsdk.api.security_role_to_function_mapping_api import SecurityRoleToFunctionMappingApi
from herdsdk.api.storage_api import StorageApi
from herdsdk.api.storage_platform_api import StoragePlatformApi
from herdsdk.api.storage_policy_api import StoragePolicyApi
from herdsdk.api.storage_unit_api import StorageUnitApi
from herdsdk.api.storage_unit_notification_registration_api import StorageUnitNotificationRegistrationApi
from herdsdk.api.subject_matter_expert_api import SubjectMatterExpertApi
from herdsdk.api.system_job_api import SystemJobApi
from herdsdk.api.tag_api import TagApi
from herdsdk.api.tag_type_api import TagTypeApi
from herdsdk.api.upload_and_download_api import UploadAndDownloadApi
from herdsdk.api.user_namespace_authorization_api import UserNamespaceAuthorizationApi



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from herdsdk.api_client import ApiClient


class TagApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def tag_create_tag(self, tag_create_request, **kwargs):  # noqa: E501
        """createTag  # noqa: E501

        Creates a new tag.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_create_tag(tag_create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TagCreateRequest tag_create_request: the information needed to create the tag (required)
        :return: Tag
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tag_create_tag_with_http_info(tag_create_request, **kwargs)  # noqa: E501
        else:
            (data) = self.tag_create_tag_with_http_info(tag_create_request, **kwargs)  # noqa: E501
            return data

    def tag_create_tag_with_http_info(self, tag_create_request, **kwargs):  # noqa: E501
        """createTag  # noqa: E501

        Creates a new tag.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_create_tag_with_http_info(tag_create_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TagCreateRequest tag_create_request: the information needed to create the tag (required)
        :return: Tag
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['tag_create_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tag_create_tag" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'tag_create_request' is set
        if ('tag_create_request' not in local_var_params or
                local_var_params['tag_create_request'] is None):
            raise ValueError("Missing the required parameter `tag_create_request` when calling `tag_create_tag`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'tag_create_request' in local_var_params:
            body_params = local_var_params['tag_create_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/tags', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Tag',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def tag_delete_tag(self, tag_type_code, tag_code, **kwargs):  # noqa: E501
        """deleteTag  # noqa: E501

        Deletes an existing tag.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_delete_tag(tag_type_code, tag_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tag_type_code: the tag type code (required)
        :param str tag_code: the tag code (required)
        :return: Tag
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tag_delete_tag_with_http_info(tag_type_code, tag_code, **kwargs)  # noqa: E501
        else:
            (data) = self.tag_delete_tag_with_http_info(tag_type_code, tag_code, **kwargs)  # noqa: E501
            return data

    def tag_delete_tag_with_http_info(self, tag_type_code, tag_code, **kwargs):  # noqa: E501
        """deleteTag  # noqa: E501

        Deletes an existing tag.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_delete_tag_with_http_info(tag_type_code, tag_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tag_type_code: the tag type code (required)
        :param str tag_code: the tag code (required)
        :return: Tag
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['tag_type_code', 'tag_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tag_delete_tag" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'tag_type_code' is set
        if ('tag_type_code' not in local_var_params or
                local_var_params['tag_type_code'] is None):
            raise ValueError("Missing the required parameter `tag_type_code` when calling `tag_delete_tag`")  # noqa: E501
        # verify the required parameter 'tag_code' is set
        if ('tag_code' not in local_var_params or
                local_var_params['tag_code'] is None):
            raise ValueError("Missing the required parameter `tag_code` when calling `tag_delete_tag`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'tag_type_code' in local_var_params:
            path_params['tagTypeCode'] = local_var_params['tag_type_code']  # noqa: E501
        if 'tag_code' in local_var_params:
            path_params['tagCode'] = local_var_params['tag_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/tags/tagTypes/{tagTypeCode}/tagCodes/{tagCode}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Tag',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def tag_get_tag(self, tag_type_code, tag_code, **kwargs):  # noqa: E501
        """getTag  # noqa: E501

        Gets an existing tag.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_get_tag(tag_type_code, tag_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tag_type_code: the tag type code (required)
        :param str tag_code: the tag code (required)
        :return: Tag
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tag_get_tag_with_http_info(tag_type_code, tag_code, **kwargs)  # noqa: E501
        else:
            (data) = self.tag_get_tag_with_http_info(tag_type_code, tag_code, **kwargs)  # noqa: E501
            return data

    def tag_get_tag_with_http_info(self, tag_type_code, tag_code, **kwargs):  # noqa: E501
        """getTag  # noqa: E501

        Gets an existing tag.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_get_tag_with_http_info(tag_type_code, tag_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tag_type_code: the tag type code (required)
        :param str tag_code: the tag code (required)
        :return: Tag
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['tag_type_code', 'tag_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tag_get_tag" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'tag_type_code' is set
        if ('tag_type_code' not in local_var_params or
                local_var_params['tag_type_code'] is None):
            raise ValueError("Missing the required parameter `tag_type_code` when calling `tag_get_tag`")  # noqa: E501
        # verify the required parameter 'tag_code' is set
        if ('tag_code' not in local_var_params or
                local_var_params['tag_code'] is None):
            raise ValueError("Missing the required parameter `tag_code` when calling `tag_get_tag`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'tag_type_code' in local_var_params:
            path_params['tagTypeCode'] = local_var_params['tag_type_code']  # noqa: E501
        if 'tag_code' in local_var_params:
            path_params['tagCode'] = local_var_params['tag_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/tags/tagTypes/{tagTypeCode}/tagCodes/{tagCode}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Tag',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def tag_get_tags(self, tag_type_code, **kwargs):  # noqa: E501
        """getTags  # noqa: E501

        Retrieves all associated tags for the specified tag type code. When tagCode is null, return all tags of the tag type code, which has no parent (i.e. root tags). When tagCode is provided, return all tags of the tag type code and whose parent tag code is tagCode.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_get_tags(tag_type_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tag_type_code: the tag type's code. (required)
        :param str tag_code: the parent tag code.
        :return: TagListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tag_get_tags_with_http_info(tag_type_code, **kwargs)  # noqa: E501
        else:
            (data) = self.tag_get_tags_with_http_info(tag_type_code, **kwargs)  # noqa: E501
            return data

    def tag_get_tags_with_http_info(self, tag_type_code, **kwargs):  # noqa: E501
        """getTags  # noqa: E501

        Retrieves all associated tags for the specified tag type code. When tagCode is null, return all tags of the tag type code, which has no parent (i.e. root tags). When tagCode is provided, return all tags of the tag type code and whose parent tag code is tagCode.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_get_tags_with_http_info(tag_type_code, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tag_type_code: the tag type's code. (required)
        :param str tag_code: the parent tag code.
        :return: TagListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['tag_type_code', 'tag_code']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tag_get_tags" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'tag_type_code' is set
        if ('tag_type_code' not in local_var_params or
                local_var_params['tag_type_code'] is None):
            raise ValueError("Missing the required parameter `tag_type_code` when calling `tag_get_tags`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'tag_type_code' in local_var_params:
            path_params['tagTypeCode'] = local_var_params['tag_type_code']  # noqa: E501

        query_params = []
        if 'tag_code' in local_var_params:
            query_params.append(('tagCode', local_var_params['tag_code']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/tags/tagTypes/{tagTypeCode}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TagListResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def tag_search_tags(self, tag_search_request, **kwargs):  # noqa: E501
        """searchTags  # noqa: E501

        Retrieves all tags existing in the system per specified search filters and keys. For each tag entity, this endpoint returns tag key by default along with any other top-level elements as specified by the \"fields\" query string parameter. The list of tags returned by this endpoint is sorted alphabetically by tag's display name ascending.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_search_tags(tag_search_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TagSearchRequest tag_search_request: the tag search request. The request can only accept a single search filter and a single search key (required)
        :param str fields: the field options for the tag type search response. The valid field options are: displayName, description, parentTagKey, hasChildren
        :return: TagSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tag_search_tags_with_http_info(tag_search_request, **kwargs)  # noqa: E501
        else:
            (data) = self.tag_search_tags_with_http_info(tag_search_request, **kwargs)  # noqa: E501
            return data

    def tag_search_tags_with_http_info(self, tag_search_request, **kwargs):  # noqa: E501
        """searchTags  # noqa: E501

        Retrieves all tags existing in the system per specified search filters and keys. For each tag entity, this endpoint returns tag key by default along with any other top-level elements as specified by the \"fields\" query string parameter. The list of tags returned by this endpoint is sorted alphabetically by tag's display name ascending.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_search_tags_with_http_info(tag_search_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param TagSearchRequest tag_search_request: the tag search request. The request can only accept a single search filter and a single search key (required)
        :param str fields: the field options for the tag type search response. The valid field options are: displayName, description, parentTagKey, hasChildren
        :return: TagSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['tag_search_request', 'fields']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tag_search_tags" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'tag_search_request' is set
        if ('tag_search_request' not in local_var_params or
                local_var_params['tag_search_request'] is None):
            raise ValueError("Missing the required parameter `tag_search_request` when calling `tag_search_tags`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'fields' in local_var_params:
            query_params.append(('fields', local_var_params['fields']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'tag_search_request' in local_var_params:
            body_params = local_var_params['tag_search_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/tags/search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TagSearchResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def tag_update_tag(self, tag_type_code, tag_code, tag_update_request, **kwargs):  # noqa: E501
        """updateTag  # noqa: E501

        Updates an existing tag.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_update_tag(tag_type_code, tag_code, tag_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tag_type_code: the tag type code (required)
        :param str tag_code: the tag code (required)
        :param TagUpdateRequest tag_update_request: the information needed to update the tag (required)
        :return: Tag
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.tag_update_tag_with_http_info(tag_type_code, tag_code, tag_update_request, **kwargs)  # noqa: E501
        else:
            (data) = self.tag_update_tag_with_http_info(tag_type_code, tag_code, tag_update_request, **kwargs)  # noqa: E501
            return data

    def tag_update_tag_with_http_info(self, tag_type_code, tag_code, tag_update_request, **kwargs):  # noqa: E501
        """updateTag  # noqa: E501

        Updates an existing tag.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.tag_update_tag_with_http_info(tag_type_code, tag_code, tag_update_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str tag_type_code: the tag type code (required)
        :param str tag_code: the tag code (required)
        :param TagUpdateRequest tag_update_request: the information needed to update the tag (required)
        :return: Tag
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['tag_type_code', 'tag_code', 'tag_update_request']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method tag_update_tag" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'tag_type_code' is set
        if ('tag_type_code' not in local_var_params or
                local_var_params['tag_type_code'] is None):
            raise ValueError("Missing the required parameter `tag_type_code` when calling `tag_update_tag`")  # noqa: E501
        # verify the required parameter 'tag_code' is set
        if ('tag_code' not in local_var_params or
                local_var_params['tag_code'] is None):
            raise ValueError("Missing the required parameter `tag_code` when calling `tag_update_tag`")  # noqa: E501
        # verify the required parameter 'tag_update_request' is set
        if ('tag_update_request' not in local_var_params or
                local_var_params['tag_update_request'] is None):
            raise ValueError("Missing the required parameter `tag_update_request` when calling `tag_update_tag`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'tag_type_code' in local_var_params:
            path_params['tagTypeCode'] = local_var_params['tag_type_code']  # noqa: E501
        if 'tag_code' in local_var_params:
            path_params['tagCode'] = local_var_params['tag_code']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'tag_update_request' in local_var_params:
            body_params = local_var_params['tag_update_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basicAuth', 'oauthAuth']  # noqa: E501

        return self.api_client.call_api(
            '/tags/tagTypes/{tagTypeCode}/tagCodes/{tagCode}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Tag',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.storage_api import StorageApi  # noqa: E501
from herdsdk.rest import ApiException


class TestStorageApi(unittest.TestCase):
    """StorageApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.storage_api.StorageApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_storage_create_storage(self):
        """Test case for storage_create_storage

        createStorage  # noqa: E501
        """
        pass

    def test_storage_delete_storage(self):
        """Test case for storage_delete_storage

        deleteStorage  # noqa: E501
        """
        pass

    def test_storage_get_storage(self):
        """Test case for storage_get_storage

        getStorage  # noqa: E501
        """
        pass

    def test_storage_get_storages(self):
        """Test case for storage_get_storages

        getStorages  # noqa: E501
        """
        pass

    def test_storage_update_storage(self):
        """Test case for storage_update_storage

        updateStorage  # noqa: E501
        """
        pass

    def test_storage_update_storage_attributes(self):
        """Test case for storage_update_storage_attributes

        updateStorageAttributes  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class EmrCluster(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'status': 'str',
        'status_change_reason': 'StatusChangeReason',
        'status_timeline': 'StatusTimeline',
        'namespace': 'str',
        'emr_cluster_definition_name': 'str',
        'emr_cluster_name': 'str',
        'account_id': 'str',
        'active_step': 'EmrStep',
        'step': 'EmrStep',
        'dry_run': 'bool',
        'emr_cluster_created': 'bool',
        'emr_cluster_definition': 'EmrClusterDefinition',
        'instance_fleets': 'list[EmrClusterInstanceFleet]'
    }

    attribute_map = {
        'id': 'id',
        'status': 'status',
        'status_change_reason': 'statusChangeReason',
        'status_timeline': 'statusTimeline',
        'namespace': 'namespace',
        'emr_cluster_definition_name': 'emrClusterDefinitionName',
        'emr_cluster_name': 'emrClusterName',
        'account_id': 'accountId',
        'active_step': 'activeStep',
        'step': 'step',
        'dry_run': 'dryRun',
        'emr_cluster_created': 'emrClusterCreated',
        'emr_cluster_definition': 'emrClusterDefinition',
        'instance_fleets': 'instanceFleets'
    }

    def __init__(self, id=None, status=None, status_change_reason=None, status_timeline=None, namespace=None, emr_cluster_definition_name=None, emr_cluster_name=None, account_id=None, active_step=None, step=None, dry_run=None, emr_cluster_created=None, emr_cluster_definition=None, instance_fleets=None):  # noqa: E501
        """EmrCluster - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._status = None
        self._status_change_reason = None
        self._status_timeline = None
        self._namespace = None
        self._emr_cluster_definition_name = None
        self._emr_cluster_name = None
        self._account_id = None
        self._active_step = None
        self._step = None
        self._dry_run = None
        self._emr_cluster_created = None
        self._emr_cluster_definition = None
        self._instance_fleets = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if status is not None:
            self.status = status
        if status_change_reason is not None:
            self.status_change_reason = status_change_reason
        if status_timeline is not None:
            self.status_timeline = status_timeline
        self.namespace = namespace
        self.emr_cluster_definition_name = emr_cluster_definition_name
        self.emr_cluster_name = emr_cluster_name
        if account_id is not None:
            self.account_id = account_id
        if active_step is not None:
            self.active_step = active_step
        if step is not None:
            self.step = step
        if dry_run is not None:
            self.dry_run = dry_run
        if emr_cluster_created is not None:
            self.emr_cluster_created = emr_cluster_created
        if emr_cluster_definition is not None:
            self.emr_cluster_definition = emr_cluster_definition
        if instance_fleets is not None:
            self.instance_fleets = instance_fleets

    @property
    def id(self):
        """Gets the id of this EmrCluster.  # noqa: E501


        :return: The id of this EmrCluster.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EmrCluster.


        :param id: The id of this EmrCluster.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def status(self):
        """Gets the status of this EmrCluster.  # noqa: E501


        :return: The status of this EmrCluster.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this EmrCluster.


        :param status: The status of this EmrCluster.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def status_change_reason(self):
        """Gets the status_change_reason of this EmrCluster.  # noqa: E501


        :return: The status_change_reason of this EmrCluster.  # noqa: E501
        :rtype: StatusChangeReason
        """
        return self._status_change_reason

    @status_change_reason.setter
    def status_change_reason(self, status_change_reason):
        """Sets the status_change_reason of this EmrCluster.


        :param status_change_reason: The status_change_reason of this EmrCluster.  # noqa: E501
        :type: StatusChangeReason
        """

        self._status_change_reason = status_change_reason

    @property
    def status_timeline(self):
        """Gets the status_timeline of this EmrCluster.  # noqa: E501


        :return: The status_timeline of this EmrCluster.  # noqa: E501
        :rtype: StatusTimeline
        """
        return self._status_timeline

    @status_timeline.setter
    def status_timeline(self, status_timeline):
        """Sets the status_timeline of this EmrCluster.


        :param status_timeline: The status_timeline of this EmrCluster.  # noqa: E501
        :type: StatusTimeline
        """

        self._status_timeline = status_timeline

    @property
    def namespace(self):
        """Gets the namespace of this EmrCluster.  # noqa: E501


        :return: The namespace of this EmrCluster.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this EmrCluster.


        :param namespace: The namespace of this EmrCluster.  # noqa: E501
        :type: str
        """
        if namespace is None:
            raise ValueError("Invalid value for `namespace`, must not be `None`")  # noqa: E501

        self._namespace = namespace

    @property
    def emr_cluster_definition_name(self):
        """Gets the emr_cluster_definition_name of this EmrCluster.  # noqa: E501


        :return: The emr_cluster_definition_name of this EmrCluster.  # noqa: E501
        :rtype: str
        """
        return self._emr_cluster_definition_name

    @emr_cluster_definition_name.setter
    def emr_cluster_definition_name(self, emr_cluster_definition_name):
        """Sets the emr_cluster_definition_name of this EmrCluster.


        :param emr_cluster_definition_name: The emr_cluster_definition_name of this EmrCluster.  # noqa: E501
        :type: str
        """
        if emr_cluster_definition_name is None:
            raise ValueError("Invalid value for `emr_cluster_definition_name`, must not be `None`")  # noqa: E501

        self._emr_cluster_definition_name = emr_cluster_definition_name

    @property
    def emr_cluster_name(self):
        """Gets the emr_cluster_name of this EmrCluster.  # noqa: E501


        :return: The emr_cluster_name of this EmrCluster.  # noqa: E501
        :rtype: str
        """
        return self._emr_cluster_name

    @emr_cluster_name.setter
    def emr_cluster_name(self, emr_cluster_name):
        """Sets the emr_cluster_name of this EmrCluster.


        :param emr_cluster_name: The emr_cluster_name of this EmrCluster.  # noqa: E501
        :type: str
        """
        if emr_cluster_name is None:
            raise ValueError("Invalid value for `emr_cluster_name`, must not be `None`")  # noqa: E501

        self._emr_cluster_name = emr_cluster_name

    @property
    def account_id(self):
        """Gets the account_id of this EmrCluster.  # noqa: E501

        The AWS account number, without dashes, where Amazon EMR service is running in  # noqa: E501

        :return: The account_id of this EmrCluster.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this EmrCluster.

        The AWS account number, without dashes, where Amazon EMR service is running in  # noqa: E501

        :param account_id: The account_id of this EmrCluster.  # noqa: E501
        :type: str
        """

        self._account_id = account_id

    @property
    def active_step(self):
        """Gets the active_step of this EmrCluster.  # noqa: E501


        :return: The active_step of this EmrCluster.  # noqa: E501
        :rtype: EmrStep
        """
        return self._active_step

    @active_step.setter
    def active_step(self, active_step):
        """Sets the active_step of this EmrCluster.


        :param active_step: The active_step of this EmrCluster.  # noqa: E501
        :type: EmrStep
        """

        self._active_step = active_step

    @property
    def step(self):
        """Gets the step of this EmrCluster.  # noqa: E501


        :return: The step of this EmrCluster.  # noqa: E501
        :rtype: EmrStep
        """
        return self._step

    @step.setter
    def step(self, step):
        """Sets the step of this EmrCluster.


        :param step: The step of this EmrCluster.  # noqa: E501
        :type: EmrStep
        """

        self._step = step

    @property
    def dry_run(self):
        """Gets the dry_run of this EmrCluster.  # noqa: E501


        :return: The dry_run of this EmrCluster.  # noqa: E501
        :rtype: bool
        """
        return self._dry_run

    @dry_run.setter
    def dry_run(self, dry_run):
        """Sets the dry_run of this EmrCluster.


        :param dry_run: The dry_run of this EmrCluster.  # noqa: E501
        :type: bool
        """

        self._dry_run = dry_run

    @property
    def emr_cluster_created(self):
        """Gets the emr_cluster_created of this EmrCluster.  # noqa: E501


        :return: The emr_cluster_created of this EmrCluster.  # noqa: E501
        :rtype: bool
        """
        return self._emr_cluster_created

    @emr_cluster_created.setter
    def emr_cluster_created(self, emr_cluster_created):
        """Sets the emr_cluster_created of this EmrCluster.


        :param emr_cluster_created: The emr_cluster_created of this EmrCluster.  # noqa: E501
        :type: bool
        """

        self._emr_cluster_created = emr_cluster_created

    @property
    def emr_cluster_definition(self):
        """Gets the emr_cluster_definition of this EmrCluster.  # noqa: E501


        :return: The emr_cluster_definition of this EmrCluster.  # noqa: E501
        :rtype: EmrClusterDefinition
        """
        return self._emr_cluster_definition

    @emr_cluster_definition.setter
    def emr_cluster_definition(self, emr_cluster_definition):
        """Sets the emr_cluster_definition of this EmrCluster.


        :param emr_cluster_definition: The emr_cluster_definition of this EmrCluster.  # noqa: E501
        :type: EmrClusterDefinition
        """

        self._emr_cluster_definition = emr_cluster_definition

    @property
    def instance_fleets(self):
        """Gets the instance_fleets of this EmrCluster.  # noqa: E501

        Describes the EC2 instances and instance configurations for clusters that use the instance fleet configuration. The instance                   fleet configuration is available only in Amazon EMR versions 4.8.0 and later, excluding 5.0.x versions                  # noqa: E501

        :return: The instance_fleets of this EmrCluster.  # noqa: E501
        :rtype: list[EmrClusterInstanceFleet]
        """
        return self._instance_fleets

    @instance_fleets.setter
    def instance_fleets(self, instance_fleets):
        """Sets the instance_fleets of this EmrCluster.

        Describes the EC2 instances and instance configurations for clusters that use the instance fleet configuration. The instance                   fleet configuration is available only in Amazon EMR versions 4.8.0 and later, excluding 5.0.x versions                  # noqa: E501

        :param instance_fleets: The instance_fleets of this EmrCluster.  # noqa: E501
        :type: list[EmrClusterInstanceFleet]
        """

        self._instance_fleets = instance_fleets

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmrCluster):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class BusinessObjectFormatAttributeDefinitionsUpdateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'attribute_definitions': 'list[AttributeDefinition]',
        'enable_business_object_data_published_attributes_change_event_notification': 'bool'
    }

    attribute_map = {
        'attribute_definitions': 'attributeDefinitions',
        'enable_business_object_data_published_attributes_change_event_notification': 'enableBusinessObjectDataPublishedAttributesChangeEventNotification'
    }

    def __init__(self, attribute_definitions=None, enable_business_object_data_published_attributes_change_event_notification=None):  # noqa: E501
        """BusinessObjectFormatAttributeDefinitionsUpdateRequest - a model defined in OpenAPI"""  # noqa: E501

        self._attribute_definitions = None
        self._enable_business_object_data_published_attributes_change_event_notification = None
        self.discriminator = None

        if attribute_definitions is not None:
            self.attribute_definitions = attribute_definitions
        if enable_business_object_data_published_attributes_change_event_notification is not None:
            self.enable_business_object_data_published_attributes_change_event_notification = enable_business_object_data_published_attributes_change_event_notification

    @property
    def attribute_definitions(self):
        """Gets the attribute_definitions of this BusinessObjectFormatAttributeDefinitionsUpdateRequest.  # noqa: E501

        A list of attribute definitions that specify attributes which are required to be specified when registering Business Object                   Data against this format. Providing a list with no elements will remove all existing attributes for the business object format                  # noqa: E501

        :return: The attribute_definitions of this BusinessObjectFormatAttributeDefinitionsUpdateRequest.  # noqa: E501
        :rtype: list[AttributeDefinition]
        """
        return self._attribute_definitions

    @attribute_definitions.setter
    def attribute_definitions(self, attribute_definitions):
        """Sets the attribute_definitions of this BusinessObjectFormatAttributeDefinitionsUpdateRequest.

        A list of attribute definitions that specify attributes which are required to be specified when registering Business Object                   Data against this format. Providing a list with no elements will remove all existing attributes for the business object format                  # noqa: E501

        :param attribute_definitions: The attribute_definitions of this BusinessObjectFormatAttributeDefinitionsUpdateRequest.  # noqa: E501
        :type: list[AttributeDefinition]
        """

        self._attribute_definitions = attribute_definitions

    @property
    def enable_business_object_data_published_attributes_change_event_notification(self):
        """Gets the enable_business_object_data_published_attributes_change_event_notification of this BusinessObjectFormatAttributeDefinitionsUpdateRequest.  # noqa: E501

        If true, enables Business Object Data Published Attributes Change Event Notification for all business object data registered                   under this business object format version                  # noqa: E501

        :return: The enable_business_object_data_published_attributes_change_event_notification of this BusinessObjectFormatAttributeDefinitionsUpdateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._enable_business_object_data_published_attributes_change_event_notification

    @enable_business_object_data_published_attributes_change_event_notification.setter
    def enable_business_object_data_published_attributes_change_event_notification(self, enable_business_object_data_published_attributes_change_event_notification):
        """Sets the enable_business_object_data_published_attributes_change_event_notification of this BusinessObjectFormatAttributeDefinitionsUpdateRequest.

        If true, enables Business Object Data Published Attributes Change Event Notification for all business object data registered                   under this business object format version                  # noqa: E501

        :param enable_business_object_data_published_attributes_change_event_notification: The enable_business_object_data_published_attributes_change_event_notification of this BusinessObjectFormatAttributeDefinitionsUpdateRequest.  # noqa: E501
        :type: bool
        """

        self._enable_business_object_data_published_attributes_change_event_notification = enable_business_object_data_published_attributes_change_event_notification

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BusinessObjectFormatAttributeDefinitionsUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class SubjectMatterExpertContactDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'full_name': 'str',
        'job_title': 'str',
        'email_address': 'str',
        'telephone_number': 'str'
    }

    attribute_map = {
        'full_name': 'fullName',
        'job_title': 'jobTitle',
        'email_address': 'emailAddress',
        'telephone_number': 'telephoneNumber'
    }

    def __init__(self, full_name=None, job_title=None, email_address=None, telephone_number=None):  # noqa: E501
        """SubjectMatterExpertContactDetails - a model defined in OpenAPI"""  # noqa: E501

        self._full_name = None
        self._job_title = None
        self._email_address = None
        self._telephone_number = None
        self.discriminator = None

        if full_name is not None:
            self.full_name = full_name
        if job_title is not None:
            self.job_title = job_title
        if email_address is not None:
            self.email_address = email_address
        if telephone_number is not None:
            self.telephone_number = telephone_number

    @property
    def full_name(self):
        """Gets the full_name of this SubjectMatterExpertContactDetails.  # noqa: E501

        The full name of the Subject Matter Expert  # noqa: E501

        :return: The full_name of this SubjectMatterExpertContactDetails.  # noqa: E501
        :rtype: str
        """
        return self._full_name

    @full_name.setter
    def full_name(self, full_name):
        """Sets the full_name of this SubjectMatterExpertContactDetails.

        The full name of the Subject Matter Expert  # noqa: E501

        :param full_name: The full_name of this SubjectMatterExpertContactDetails.  # noqa: E501
        :type: str
        """

        self._full_name = full_name

    @property
    def job_title(self):
        """Gets the job_title of this SubjectMatterExpertContactDetails.  # noqa: E501

        The job title of the Subject Matter Expert  # noqa: E501

        :return: The job_title of this SubjectMatterExpertContactDetails.  # noqa: E501
        :rtype: str
        """
        return self._job_title

    @job_title.setter
    def job_title(self, job_title):
        """Sets the job_title of this SubjectMatterExpertContactDetails.

        The job title of the Subject Matter Expert  # noqa: E501

        :param job_title: The job_title of this SubjectMatterExpertContactDetails.  # noqa: E501
        :type: str
        """

        self._job_title = job_title

    @property
    def email_address(self):
        """Gets the email_address of this SubjectMatterExpertContactDetails.  # noqa: E501

        The e-mail address of the Subject Matter Expert  # noqa: E501

        :return: The email_address of this SubjectMatterExpertContactDetails.  # noqa: E501
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this SubjectMatterExpertContactDetails.

        The e-mail address of the Subject Matter Expert  # noqa: E501

        :param email_address: The email_address of this SubjectMatterExpertContactDetails.  # noqa: E501
        :type: str
        """

        self._email_address = email_address

    @property
    def telephone_number(self):
        """Gets the telephone_number of this SubjectMatterExpertContactDetails.  # noqa: E501

        The telephone number of the Subject Matter Expert  # noqa: E501

        :return: The telephone_number of this SubjectMatterExpertContactDetails.  # noqa: E501
        :rtype: str
        """
        return self._telephone_number

    @telephone_number.setter
    def telephone_number(self, telephone_number):
        """Sets the telephone_number of this SubjectMatterExpertContactDetails.

        The telephone number of the Subject Matter Expert  # noqa: E501

        :param telephone_number: The telephone_number of this SubjectMatterExpertContactDetails.  # noqa: E501
        :type: str
        """

        self._telephone_number = telephone_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SubjectMatterExpertContactDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import herdsdk
from herdsdk.api.namespace_api import NamespaceApi  # noqa: E501
from herdsdk.rest import ApiException


class TestNamespaceApi(unittest.TestCase):
    """NamespaceApi unit test stubs"""

    def setUp(self):
        self.api = herdsdk.api.namespace_api.NamespaceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_namespace_create_namespace(self):
        """Test case for namespace_create_namespace

        createNamespace  # noqa: E501
        """
        pass

    def test_namespace_delete_namespace(self):
        """Test case for namespace_delete_namespace

        deleteNamespace  # noqa: E501
        """
        pass

    def test_namespace_get_namespace(self):
        """Test case for namespace_get_namespace

        getNamespace  # noqa: E501
        """
        pass

    def test_namespace_get_namespaces(self):
        """Test case for namespace_get_namespaces

        getNamespaces  # noqa: E501
        """
        pass

    def test_namespace_search_namespaces(self):
        """Test case for namespace_search_namespaces

        searchNamespaces  # noqa: E501
        """
        pass

    def test_namespace_update_namespaces(self):
        """Test case for namespace_update_namespaces

        updateNamespaces  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class RelationalTableRegistrationCreateRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'namespace': 'str',
        'business_object_definition_name': 'str',
        'business_object_definition_display_name': 'str',
        'business_object_format_usage': 'str',
        'data_provider_name': 'str',
        'relational_schema_name': 'str',
        'relational_table_name': 'str',
        'storage_name': 'str'
    }

    attribute_map = {
        'namespace': 'namespace',
        'business_object_definition_name': 'businessObjectDefinitionName',
        'business_object_definition_display_name': 'businessObjectDefinitionDisplayName',
        'business_object_format_usage': 'businessObjectFormatUsage',
        'data_provider_name': 'dataProviderName',
        'relational_schema_name': 'relationalSchemaName',
        'relational_table_name': 'relationalTableName',
        'storage_name': 'storageName'
    }

    def __init__(self, namespace=None, business_object_definition_name=None, business_object_definition_display_name=None, business_object_format_usage=None, data_provider_name=None, relational_schema_name=None, relational_table_name=None, storage_name=None):  # noqa: E501
        """RelationalTableRegistrationCreateRequest - a model defined in OpenAPI"""  # noqa: E501

        self._namespace = None
        self._business_object_definition_name = None
        self._business_object_definition_display_name = None
        self._business_object_format_usage = None
        self._data_provider_name = None
        self._relational_schema_name = None
        self._relational_table_name = None
        self._storage_name = None
        self.discriminator = None

        self.namespace = namespace
        self.business_object_definition_name = business_object_definition_name
        if business_object_definition_display_name is not None:
            self.business_object_definition_display_name = business_object_definition_display_name
        self.business_object_format_usage = business_object_format_usage
        self.data_provider_name = data_provider_name
        self.relational_schema_name = relational_schema_name
        self.relational_table_name = relational_table_name
        self.storage_name = storage_name

    @property
    def namespace(self):
        """Gets the namespace of this RelationalTableRegistrationCreateRequest.  # noqa: E501

        The Namespace to which a Business Object Format is related  # noqa: E501

        :return: The namespace of this RelationalTableRegistrationCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """Sets the namespace of this RelationalTableRegistrationCreateRequest.

        The Namespace to which a Business Object Format is related  # noqa: E501

        :param namespace: The namespace of this RelationalTableRegistrationCreateRequest.  # noqa: E501
        :type: str
        """
        if namespace is None:
            raise ValueError("Invalid value for `namespace`, must not be `None`")  # noqa: E501

        self._namespace = namespace

    @property
    def business_object_definition_name(self):
        """Gets the business_object_definition_name of this RelationalTableRegistrationCreateRequest.  # noqa: E501

        The name of the Business Object Definition to which a Business Object Format is related  # noqa: E501

        :return: The business_object_definition_name of this RelationalTableRegistrationCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_definition_name

    @business_object_definition_name.setter
    def business_object_definition_name(self, business_object_definition_name):
        """Sets the business_object_definition_name of this RelationalTableRegistrationCreateRequest.

        The name of the Business Object Definition to which a Business Object Format is related  # noqa: E501

        :param business_object_definition_name: The business_object_definition_name of this RelationalTableRegistrationCreateRequest.  # noqa: E501
        :type: str
        """
        if business_object_definition_name is None:
            raise ValueError("Invalid value for `business_object_definition_name`, must not be `None`")  # noqa: E501

        self._business_object_definition_name = business_object_definition_name

    @property
    def business_object_definition_display_name(self):
        """Gets the business_object_definition_display_name of this RelationalTableRegistrationCreateRequest.  # noqa: E501

        The display name of the business object definition                  # noqa: E501

        :return: The business_object_definition_display_name of this RelationalTableRegistrationCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_definition_display_name

    @business_object_definition_display_name.setter
    def business_object_definition_display_name(self, business_object_definition_display_name):
        """Sets the business_object_definition_display_name of this RelationalTableRegistrationCreateRequest.

        The display name of the business object definition                  # noqa: E501

        :param business_object_definition_display_name: The business_object_definition_display_name of this RelationalTableRegistrationCreateRequest.  # noqa: E501
        :type: str
        """

        self._business_object_definition_display_name = business_object_definition_display_name

    @property
    def business_object_format_usage(self):
        """Gets the business_object_format_usage of this RelationalTableRegistrationCreateRequest.  # noqa: E501

        The Usage of this Business Object Format - a string describing how this format is used. Often used as a label for the Business                   Object Format                  # noqa: E501

        :return: The business_object_format_usage of this RelationalTableRegistrationCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._business_object_format_usage

    @business_object_format_usage.setter
    def business_object_format_usage(self, business_object_format_usage):
        """Sets the business_object_format_usage of this RelationalTableRegistrationCreateRequest.

        The Usage of this Business Object Format - a string describing how this format is used. Often used as a label for the Business                   Object Format                  # noqa: E501

        :param business_object_format_usage: The business_object_format_usage of this RelationalTableRegistrationCreateRequest.  # noqa: E501
        :type: str
        """
        if business_object_format_usage is None:
            raise ValueError("Invalid value for `business_object_format_usage`, must not be `None`")  # noqa: E501

        self._business_object_format_usage = business_object_format_usage

    @property
    def data_provider_name(self):
        """Gets the data_provider_name of this RelationalTableRegistrationCreateRequest.  # noqa: E501

        The name of the data provider  # noqa: E501

        :return: The data_provider_name of this RelationalTableRegistrationCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._data_provider_name

    @data_provider_name.setter
    def data_provider_name(self, data_provider_name):
        """Sets the data_provider_name of this RelationalTableRegistrationCreateRequest.

        The name of the data provider  # noqa: E501

        :param data_provider_name: The data_provider_name of this RelationalTableRegistrationCreateRequest.  # noqa: E501
        :type: str
        """
        if data_provider_name is None:
            raise ValueError("Invalid value for `data_provider_name`, must not be `None`")  # noqa: E501

        self._data_provider_name = data_provider_name

    @property
    def relational_schema_name(self):
        """Gets the relational_schema_name of this RelationalTableRegistrationCreateRequest.  # noqa: E501

        The relational schema name. A schema name must match the actual schema name as it is stored in the relational database                  # noqa: E501

        :return: The relational_schema_name of this RelationalTableRegistrationCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._relational_schema_name

    @relational_schema_name.setter
    def relational_schema_name(self, relational_schema_name):
        """Sets the relational_schema_name of this RelationalTableRegistrationCreateRequest.

        The relational schema name. A schema name must match the actual schema name as it is stored in the relational database                  # noqa: E501

        :param relational_schema_name: The relational_schema_name of this RelationalTableRegistrationCreateRequest.  # noqa: E501
        :type: str
        """
        if relational_schema_name is None:
            raise ValueError("Invalid value for `relational_schema_name`, must not be `None`")  # noqa: E501

        self._relational_schema_name = relational_schema_name

    @property
    def relational_table_name(self):
        """Gets the relational_table_name of this RelationalTableRegistrationCreateRequest.  # noqa: E501

        The relational table name. A table name must match the actual table name as it is stored in the relational database                  # noqa: E501

        :return: The relational_table_name of this RelationalTableRegistrationCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._relational_table_name

    @relational_table_name.setter
    def relational_table_name(self, relational_table_name):
        """Sets the relational_table_name of this RelationalTableRegistrationCreateRequest.

        The relational table name. A table name must match the actual table name as it is stored in the relational database                  # noqa: E501

        :param relational_table_name: The relational_table_name of this RelationalTableRegistrationCreateRequest.  # noqa: E501
        :type: str
        """
        if relational_table_name is None:
            raise ValueError("Invalid value for `relational_table_name`, must not be `None`")  # noqa: E501

        self._relational_table_name = relational_table_name

    @property
    def storage_name(self):
        """Gets the storage_name of this RelationalTableRegistrationCreateRequest.  # noqa: E501

        The name of the storage  # noqa: E501

        :return: The storage_name of this RelationalTableRegistrationCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._storage_name

    @storage_name.setter
    def storage_name(self, storage_name):
        """Sets the storage_name of this RelationalTableRegistrationCreateRequest.

        The name of the storage  # noqa: E501

        :param storage_name: The storage_name of this RelationalTableRegistrationCreateRequest.  # noqa: E501
        :type: str
        """
        if storage_name is None:
            raise ValueError("Invalid value for `storage_name`, must not be `None`")  # noqa: E501

        self._storage_name = storage_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RelationalTableRegistrationCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    herd

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    OpenAPI spec version: 0.178.0-SNAPSHOT
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six


class PartitionValueFilter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'partition_key': 'str',
        'partition_values': 'list[str]',
        'partition_value_range': 'PartitionValueRange',
        'latest_before_partition_value': 'LatestBeforePartitionValue',
        'latest_after_partition_value': 'LatestAfterPartitionValue'
    }

    attribute_map = {
        'partition_key': 'partitionKey',
        'partition_values': 'partitionValues',
        'partition_value_range': 'partitionValueRange',
        'latest_before_partition_value': 'latestBeforePartitionValue',
        'latest_after_partition_value': 'latestAfterPartitionValue'
    }

    def __init__(self, partition_key=None, partition_values=None, partition_value_range=None, latest_before_partition_value=None, latest_after_partition_value=None):  # noqa: E501
        """PartitionValueFilter - a model defined in OpenAPI"""  # noqa: E501

        self._partition_key = None
        self._partition_values = None
        self._partition_value_range = None
        self._latest_before_partition_value = None
        self._latest_after_partition_value = None
        self.discriminator = None

        if partition_key is not None:
            self.partition_key = partition_key
        if partition_values is not None:
            self.partition_values = partition_values
        if partition_value_range is not None:
            self.partition_value_range = partition_value_range
        if latest_before_partition_value is not None:
            self.latest_before_partition_value = latest_before_partition_value
        if latest_after_partition_value is not None:
            self.latest_after_partition_value = latest_after_partition_value

    @property
    def partition_key(self):
        """Gets the partition_key of this PartitionValueFilter.  # noqa: E501

        The Partition Key for a Business Object Data. This must be they Partition Key specified in the Business Object Format. Required                   when partitionValueFilters is present                  # noqa: E501

        :return: The partition_key of this PartitionValueFilter.  # noqa: E501
        :rtype: str
        """
        return self._partition_key

    @partition_key.setter
    def partition_key(self, partition_key):
        """Sets the partition_key of this PartitionValueFilter.

        The Partition Key for a Business Object Data. This must be they Partition Key specified in the Business Object Format. Required                   when partitionValueFilters is present                  # noqa: E501

        :param partition_key: The partition_key of this PartitionValueFilter.  # noqa: E501
        :type: str
        """

        self._partition_key = partition_key

    @property
    def partition_values(self):
        """Gets the partition_values of this PartitionValueFilter.  # noqa: E501

        This specifies a list of partition values. Required when partitionValueRange, latestBeforePartitionValue, or                   latestAfterPartitionValue is not present                  # noqa: E501

        :return: The partition_values of this PartitionValueFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._partition_values

    @partition_values.setter
    def partition_values(self, partition_values):
        """Sets the partition_values of this PartitionValueFilter.

        This specifies a list of partition values. Required when partitionValueRange, latestBeforePartitionValue, or                   latestAfterPartitionValue is not present                  # noqa: E501

        :param partition_values: The partition_values of this PartitionValueFilter.  # noqa: E501
        :type: list[str]
        """

        self._partition_values = partition_values

    @property
    def partition_value_range(self):
        """Gets the partition_value_range of this PartitionValueFilter.  # noqa: E501


        :return: The partition_value_range of this PartitionValueFilter.  # noqa: E501
        :rtype: PartitionValueRange
        """
        return self._partition_value_range

    @partition_value_range.setter
    def partition_value_range(self, partition_value_range):
        """Sets the partition_value_range of this PartitionValueFilter.


        :param partition_value_range: The partition_value_range of this PartitionValueFilter.  # noqa: E501
        :type: PartitionValueRange
        """

        self._partition_value_range = partition_value_range

    @property
    def latest_before_partition_value(self):
        """Gets the latest_before_partition_value of this PartitionValueFilter.  # noqa: E501


        :return: The latest_before_partition_value of this PartitionValueFilter.  # noqa: E501
        :rtype: LatestBeforePartitionValue
        """
        return self._latest_before_partition_value

    @latest_before_partition_value.setter
    def latest_before_partition_value(self, latest_before_partition_value):
        """Sets the latest_before_partition_value of this PartitionValueFilter.


        :param latest_before_partition_value: The latest_before_partition_value of this PartitionValueFilter.  # noqa: E501
        :type: LatestBeforePartitionValue
        """

        self._latest_before_partition_value = latest_before_partition_value

    @property
    def latest_after_partition_value(self):
        """Gets the latest_after_partition_value of this PartitionValueFilter.  # noqa: E501


        :return: The latest_after_partition_value of this PartitionValueFilter.  # noqa: E501
        :rtype: LatestAfterPartitionValue
        """
        return self._latest_after_partition_value

    @latest_after_partition_value.setter
    def latest_after_partition_value(self, latest_after_partition_value):
        """Sets the latest_after_partition_value of this PartitionValueFilter.


        :param latest_after_partition_value: The latest_after_partition_value of this PartitionValueFilter.  # noqa: E501
        :type: LatestAfterPartitionValue
        """

        self._latest_after_partition_value = latest_after_partition_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PartitionValueFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
